pub struct AinlMemoryNode {
pub id: Uuid,
pub node_type: AinlNodeType,
pub timestamp: i64,
pub edges: Vec<AinlEdge>,
}Expand description
A node in the AINL memory graph
Fields
id: Uuidnode_type: AinlNodeTypetimestamp: i64edges: Vec<AinlEdge>Implementations
Sourceimpl AinlMemoryNode
impl AinlMemoryNode
Sourcepub fn new_delegation_episode(
agent_id: String,
delegated_to: String,
trace_id: String,
depth: u32,
) -> Self
pub fn new_delegation_episode( agent_id: String, delegated_to: String, trace_id: String, depth: u32, ) -> Self
Create a new episode node for an orchestration delegation
Sourcepub fn new_tool_episode(agent_id: String, tool_name: String) -> Self
pub fn new_tool_episode(agent_id: String, tool_name: String) -> Self
Create a new episode node for a tool use